import configparser
import os


class Config:
    CONFIG_FILE_PATH = os.getenv("CONFIG_FILE_PATH", "/opt/vmware/config/config.ini")
    CONFIG = configparser.ConfigParser()
    CONFIG.read(CONFIG_FILE_PATH)

    # =============================== WARMING ============================================

    RETRY_COUNT = CONFIG.getint("WARMING", "RETRY_COUNT", fallback=120)

    RETRY_FREQUENCY_SECONDS = CONFIG.getint("WARMING", "RETRY_FREQUENCY_SECONDS", fallback=60)

    # =============================== LOGGING ============================================
    LOGGING_LEVEL = CONFIG.get("LOGGING", "LEVEL", fallback="INFO")

    LOGGING_FORMAT = CONFIG.get(
        "LOGGING",
        "FORMAT",
        fallback="%(asctime)s - [%(threadName)s] -  %(name)s - %(levelname)s - %(message)s",
    )

    # ================================ DRUID =============================================
    QUERY_ID_PREFIX = CONFIG.get("DRUID", "QUERY_ID_PREFIX", fallback="NsxIntelligence-")

    DRUID_URL = CONFIG.get("DRUID", "DRUID_URL", fallback="https://druid-router:8280")

    INTERVAL_TEMPLATE = CONFIG.get("DRUID", "INTERVAL_TEMPLATE", fallback="%Y-%m-%dT%H:%M:%S.%f")

    DRUID_QUERY_TEMPLATE_FILEPATH = CONFIG.get(
        "DRUID",
        "DRUID_QUERY_TEMPLATE_FILEPATH",
        fallback="/opt/vmware/intelligence/redis/cache-warming/resources/druid_query_template.json",
    )

    # ================================ REDIS =============================================
    CERT_PATH = CONFIG.get("REDIS", "CERT_PATH", fallback="/etc/certs")

    CA_CERT = CONFIG.get("REDIS", "CA_CERT", fallback="ca.crt")

    KEY_CERT = CONFIG.get("REDIS", "KEY_CERT", fallback="tls.key")

    PUBLIC_CERT = CONFIG.get("REDIS", "PUBLIC_CERT", fallback="tls.crt")

    REDIS_PASSWORD_ENV = CONFIG.get("REDIS", "REDIS_PASSWORD_ENV", fallback="REDIS_PASSWORD")

    REDIS_HOST = CONFIG.get("REDIS", "REDIS_HOST", fallback="redis-cluster")

    REDIS_PORT = CONFIG.getint("REDIS", "REDIS_PORT", fallback=6379)

    MAX_FLOW_COUNT = CONFIG.getint("REDIS", "MAX_FLOW_COUNT", fallback=1000000)

    MSET_REDIS_DATA_BLOCK_SIZE = CONFIG.getint("REDIS", "MSET_REDIS_DATA_BLOCK_SIZE", fallback=500000)

    SITE_INFO_MAP_KEY = CONFIG.get("REDIS", "SITE_INFO_MAP_KEY", fallback="Site_Info_Map")

    LATEST_FLOW_DATA_MAP_IDENTIFIER = CONFIG.get(
        "REDIS", "LATEST_FLOW_DATA_MAP_IDENTIFIER", fallback="LatestFlowDataMap"
    )

    LATEST_FLOW_DATA_SET_IDENTIFIER = CONFIG.get(
        "REDIS", "LATEST_FLOW_DATA_SET_IDENTIFIER", fallback="LatestFlowDataSortedSet"
    )

    TOTALFLOW_MAP_IDENTIFIER = CONFIG.get("REDIS", "TOTALFLOW_MAP_IDENTIFIER", fallback="TotalFlowDataMetricsMap")

    TOTALFLOW_SET_IDENTIFIER = CONFIG.get("REDIS", "TOTALFLOW_SET_IDENTIFIER", fallback="TotalFlowDataMetricsSortedSet")

    WORKLOAD_MAP_IDENTIFIER = CONFIG.get("REDIS", "WORKLOAD_MAP_IDENTIFIER", fallback="WorkloadDataConfigMetricsMap")

    WORKLOAD_SET_IDENTIFIER = CONFIG.get(
        "REDIS",
        "WORKLOAD_SET_IDENTIFIER",
        fallback="WorkloadDataConfigMetricsSortedSet",
    )

    MONITOR_METRICS_IDENTIFIER = CONFIG.get("REDIS", "MONITOR_METRICS_IDENTIFIER", fallback="MonitorMetricsMap")

    # ============================== SITE SERVICE ========================================

    SITE_SERVICE_URL = CONFIG.get(
        "SITE_SERVICE", "SITE_SERVICE_URL", fallback="https://site-service:8710/api/v1/intelligence/site-service"
    )

    GET_SITE_ID_RETRY_COUNT = CONFIG.getint("SITE_SERVICE", "GET_SITE_ID_RETRY_COUNT", fallback=120)

    GET_SITE_ID_RETRY_FREQUENCY_SECONDS = CONFIG.getint(
        "SITE_SERVICE", "GET_SITE_ID_RETRY_FREQUENCY_SECONDS", fallback=30
    )
