import os

import requests
from requests.adapters import HTTPAdapter, Retry

from src.config import Config


def retry_session(retries: int, backoff_factor: int = 2) -> requests.Session:
    session = requests.Session()
    retry = Retry(
        total=retries,
        read=retries,
        connect=retries,
        backoff_factor=backoff_factor,
        allowed_methods=None,  # confusingly, allowed_methods None should retry on any HTTP verb
    )
    adapter = HTTPAdapter(max_retries=retry)
    session.mount("https://", adapter)
    session.cert = (
        os.path.join(Config.CERT_PATH, Config.PUBLIC_CERT),
        os.path.join(Config.CERT_PATH, Config.KEY_CERT),
    )
    session.verify = os.path.join(Config.CERT_PATH, Config.CA_CERT)
    return session
